# Simple Calculator

A simple calculator package for basic math operations.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install simple-calculator-muharram-nizar.

```bash
pip install simple-calculator-muharram-nizar
```

## Usage

```python
from simple_calculator_muharram_nizar import calc

# Add
calc.main("1+1")

# Subtract
calc.main("5-2")

# Multiply
calc.main("3*3")

# Divide
calc.main("10/2")
```


